@@ -9,8 +9,11 @@ from collections import OrderedDict
 
 import sparkmagic.utils.configuration as conf
 import sparkmagic.utils.constants as constants
-from sparkmagic.livyclientlib.exceptions import BadUserDataException, DataFrameParseException, \
-    BadUserConfigurationException
+from sparkmagic.livyclientlib.exceptions import (
+    BadUserDataException,
+    DataFrameParseException,
+    BadUserConfigurationException,
+)
 
 
 def get_coerce_value(coerce):
@@ -27,12 +30,12 @@ def parse_argstring_or_throw(magic_func, argstring, parse_argstring=parse_argstr
         return parse_argstring(magic_func, argstring)
     except UsageError as e:
         raise BadUserDataException(str(e))
-        
-        
+
+
 def coerce_pandas_df_to_numeric_datetime(df):
     for column_name in df.columns:
         coerced = False
-        
+
         if df[column_name].isnull().all():
             continue
 
@@ -52,19 +55,21 @@ def coerce_pandas_df_to_numeric_datetime(df):
 
 
 def records_to_dataframe(records_text, kind, coerce=None):
-    if records_text in ['', '[]']:
+    if records_text in ["", "[]"]:
         strings = []
     else:
-        strings = records_text.strip().split('\n')
+        strings = records_text.strip().split("\n")
     try:
-        data_array = [json.JSONDecoder(object_pairs_hook=OrderedDict).decode(s) for s in strings]
+        data_array = [
+            json.JSONDecoder(object_pairs_hook=OrderedDict).decode(s) for s in strings
+        ]
 
         if kind == constants.SESSION_KIND_SPARKR and len(data_array) > 0:
             data_array = data_array[0]
 
         df = pd.DataFrame(data_array)
 
-        if len(data_array) > 0:    
+        if len(data_array) > 0:
             # This will assign the columns in the right order. If we simply did
             # df = pd.DataFrame(data_array, columns=data_array[0].keys())
             # in the code defining df, above, we could get an issue where the first element
@@ -75,7 +80,7 @@ def records_to_dataframe(records_text, kind, coerce=None):
                 if len(data.keys()) == len(df.columns):
                     df = df[list(data.keys())]
                     break
-                    
+
         if coerce is None:
             coerce = conf.coerce_dataframe()
         if coerce:
@@ -83,17 +88,24 @@ def records_to_dataframe(records_text, kind, coerce=None):
 
         return df
     except ValueError:
-        raise DataFrameParseException(u"Cannot parse object as JSON: '{}'".format(strings))
+        raise DataFrameParseException(
+            "Cannot parse object as JSON: '{}'".format(strings)
+        )
 
 
 def get_sessions_info_html(info_sessions, current_session_id):
-    html = u"""<table>
-<tr><th>ID</th><th>YARN Application ID</th><th>Kind</th><th>State</th><th>Spark UI</th><th>Driver log</th><th>User</th><th>Current session?</th></tr>""" + \
-    u"".join([session.get_row_html(current_session_id) for session in info_sessions]) + \
-    u"</table>"
+    html = (
+        """<table>
+<tr><th>ID</th><th>YARN Application ID</th><th>Kind</th><th>State</th><th>Spark UI</th><th>Driver log</th><th>User</th><th>Current session?</th></tr>"""
+        + "".join(
+            [session.get_row_html(current_session_id) for session in info_sessions]
+        )
+        + "</table>"
+    )
 
     return html
 
+
 def initialize_auth(args):
     """Creates an authenticatior class instance for the given auth type
 
@@ -103,10 +115,10 @@ def initialize_auth(args):
 
     Returns:
         An instance of a valid Authenticator or None if args.auth is 'None'
-    
+
     Raises:
         sparkmagic.livyclientlib.BadUserConfigurationException: if args.auth is not a valid
-        authenticator class. 
+        authenticator class.
     """
     if args.auth is None:
         auth = conf.get_auth_value(args.user, args.password)
@@ -114,16 +126,18 @@ def initialize_auth(args):
         auth = args.auth
     if auth == constants.NO_AUTH:
         return None
-    else: 
+    else:
         full_class = conf.authenticators().get(auth)
         if full_class is None:
-            raise BadUserConfigurationException(u"Auth '{}' not supported".format(auth))
-        module, class_name = (full_class).rsplit('.', 1)
+            raise BadUserConfigurationException("Auth '{}' not supported".format(auth))
+        module, class_name = (full_class).rsplit(".", 1)
         events_handler_module = importlib.import_module(module)
         auth_class = getattr(events_handler_module, class_name)
         return auth_class(args)
 
+
 class Namespace:
     """Namespace to initialize authenticator class with"""
+
     def __init__(self, **kwargs):
         self.__dict__.update(kwargs)
